mario.plugins package
=====================

Submodules
----------

mario.plugins.basic module
--------------------------

.. automodule:: mario.plugins.basic
   :members:
   :undoc-members:
   :show-inheritance:

mario.plugins.read module
-------------------------

.. automodule:: mario.plugins.read
   :members:
   :undoc-members:
   :show-inheritance:

mario.plugins.write module
--------------------------

.. automodule:: mario.plugins.write
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: mario.plugins
   :members:
   :undoc-members:
   :show-inheritance:
